@@ -1,52 +1,26 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.documentconverter;
 
 import java.io.File;
@@ -63,7 +37,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 import org.apache.commons.io.FileUtils;
-import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 
 /**
@@ -236,7 +209,8 @@ public class AsyncExecutor implements ICounter {
                 logDebug("DC started asynchronous conversion", m_jobProperties);
 
                 final HashMap<String, Object> resultProperties = new HashMap<>(8);
-                IOUtils.closeQuietly(m_documentConverter.convert(m_jobType, m_jobProperties, resultProperties));
+
+                DocumentConverterManager.close(m_documentConverter.convert(m_jobType, m_jobProperties, resultProperties));
 
                 // increment run counter by one
                 m_ranCounter.incrementAndGet();
@@ -293,11 +267,12 @@ public class AsyncExecutor implements ICounter {
                 asyncHashBuilder.append(remoteCashHash).append('-');
             } else {
                 final File inputFile = (File) m_jobProperties.get(Properties.PROP_INPUT_FILE);
+                final String inputURL = (String) m_jobProperties.get(Properties.PROP_INPUT_URL);
                 final String locale = (String) m_jobProperties.get(Properties.PROP_LOCALE);
-                final StringBuilder fileHashBuilder = DocumentConverterManager.getFileHashBuilder(inputFile, locale);
+                final StringBuilder fileHashBuilder = DocumentConverterManager.getFileHashBuilder(inputFile, inputURL, locale);
 
                 if (null != fileHashBuilder) {
-                    asyncHashBuilder.append(m_jobType).append('-').append(DocumentConverterManager.getFileHashBuilder(inputFile, locale).toString());
+                    asyncHashBuilder.append(m_jobType).append('-').append(fileHashBuilder.toString());
                 } else {
                     asyncHashBuilder = null;
                 }
