@@ -1,55 +1,30 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 
+
+
 package com.openexchange.documentconverter;
 
+import java.io.Closeable;
 import java.io.EOFException;
 import java.io.File;
 import java.io.FileInputStream;
@@ -61,6 +36,7 @@ import java.net.SocketTimeoutException;
 import java.net.URL;
 import java.net.URLConnection;
 import java.net.URLDecoder;
+import java.net.URLEncoder;
 import java.util.HashMap;
 import java.util.zip.CheckedInputStream;
 import org.apache.commons.io.FileUtils;
@@ -71,6 +47,9 @@ import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.common.base.Throwables;
+import com.openexchange.exception.Category;
+import com.openexchange.exception.LogLevel;
+import com.openexchange.exception.OXException;
 import jonelo.jacksum.JacksumAPI;
 import jonelo.jacksum.algorithm.AbstractChecksum;
 
@@ -97,7 +76,7 @@ public class DocumentConverterManager {
 
     final private static int HTTP_CACHESERVER_READ_TIMEOUT_MS=60000;
 
-    final private static String UNKNOWN_FILENAME = "n/a";
+    final private static String STR_NOT_AVAILABLE = "n/a";
 
     final private static String[] BASH_SEARCH_PATHES = {
         "/bin/bash",
@@ -107,7 +86,6 @@ public class DocumentConverterManager {
         "/usr/local/sbin/bash"
     };
 
-
     /**
      * Initializes a new {@link DocumentConverterManager}.
      */
@@ -301,7 +279,7 @@ public class DocumentConverterManager {
      * @param locale The locale to be used, might be 'null'
      * @return
      */
-    public static StringBuilder getFileHashBuilder(File file, String locale) {
+    public static StringBuilder getFileHashBuilder(File file, @Nullable String fileURL, @Nullable String locale) {
         StringBuilder hashBuilder = null;
 
         if (null != file) {
@@ -319,6 +297,20 @@ public class DocumentConverterManager {
                 }
 
                 hashBuilder.append(checksum.getFormattedValue());
+
+                if (null != fileURL) {
+                    try {
+                        // append the hash code of the possibly given fileURL (converted to an
+                        // unsigned long value) since we need different hashes in case of fields
+                        // within the document that are evaluated at conversion time of the document
+                        hashBuilder.append('_').append(Integer.toUnsignedLong(URLEncoder.encode(fileURL, "UTF-8").hashCode()));
+                    } catch (UnsupportedEncodingException e) {
+                        // remove last underscore in case of Exception
+                        hashBuilder.setLength(hashBuilder.length() - 1);
+                        DocumentConverterManager.logExcp(e);
+                    }
+                }
+
                 hashBuilder.append('-');
             } catch (final Exception e) {
                 logExcp(e);
@@ -375,7 +367,7 @@ public class DocumentConverterManager {
         try {
             return (null != filename) ?
                 URLDecoder.decode(filename.replaceAll("%(?![0-9a-fA-F]{2})", "%25"), "UTF-8") :
-                    UNKNOWN_FILENAME;
+                    STR_NOT_AVAILABLE;
         } catch (@SuppressWarnings("unused") final UnsupportedEncodingException e) {
             // ok
         }
@@ -450,6 +442,19 @@ public class DocumentConverterManager {
 
     }
 
+    /**
+     * @param closeable
+     */
+    public static void close(final Closeable closeable) {
+        if (null != closeable) {
+            try {
+                closeable.close();
+            } catch (IOException e) {
+                logExcp(e);
+            }
+        }
+    }
+
     /**
      * Method impl. is copied from Process#waitFor(long timeout, TimeUnit unit) method
      * with the difference that this method returns the exit code of the process in case
@@ -626,36 +631,76 @@ public class DocumentConverterManager {
      * @param e
      */
     static public void logExcp(Exception e) {
-        if (isLogError()) {
-            final Throwable rootCause = Throwables.getRootCause(e);
-            final String rootCauseMessage = (null != rootCause) ? rootCause.getMessage() : "n/a";
-            final String lowerCaseRootCauseMessage = (null != rootCauseMessage) ? rootCauseMessage.toLowerCase() : "n/a";
-            String message = e.getMessage();
+        final Throwable rootCause = Throwables.getRootCause(e);
+        final String rootCauseMessage = (null != rootCause) ? rootCause.getMessage() : STR_NOT_AVAILABLE;
+        final String lowerCaseRootCauseMessage = (null != rootCauseMessage) ? rootCauseMessage.toLowerCase() : STR_NOT_AVAILABLE;
+        String logMessage = null;
 
-            if ((rootCause instanceof SocketException) ||
-                (rootCause instanceof SocketTimeoutException) ||
-                (rootCause instanceof EOFException) ||
-                ((rootCause instanceof IOException) &&
-                 ((lowerCaseRootCauseMessage.contains("broken pipe") || lowerCaseRootCauseMessage.contains(("connection reset")) || lowerCaseRootCauseMessage.contains(("invalid stream")))))) {
+        if (StringUtils.isNotEmpty(rootCauseMessage)) {
+            if (rootCauseMessage.length() > Properties.MAX_ERROR_MESSAGE_TOTAL_LENGTH) {
+                final String fillStr = "...";
+                final int beginLength = Properties.MAX_ERROR_MESSAGE_TOTAL_LENGTH - Properties.MAX_ERROR_MESSAGE_END_LENGTH - fillStr.length();
+                final int endLength = Math.min(rootCauseMessage.length() - beginLength, Properties.MAX_ERROR_MESSAGE_END_LENGTH);
 
-                // ignore but trace socket exceptions; these may occur, when a connection timeout has happened
-                LOG.trace(implGetLogMessage("DC caught an ignorable connection exception: \n" + message, null));
+                logMessage = rootCauseMessage.substring(0, beginLength) + ((endLength > 0) ? ("..." + rootCauseMessage.substring(rootCauseMessage.length() - endLength)) : "");
             } else {
-                if (StringUtils.isNotEmpty(message)) {
-                    if (message.length() > Properties.MAX_ERROR_MESSAGE_TOTAL_LENGTH) {
-                        final String fillStr = "...";
-                        final int beginLength = Properties.MAX_ERROR_MESSAGE_TOTAL_LENGTH - Properties.MAX_ERROR_MESSAGE_END_LENGTH - fillStr.length();
-                        final int endLength = Math.min(message.length() - beginLength, Properties.MAX_ERROR_MESSAGE_END_LENGTH);
-                        message = message.substring(0, beginLength) + ((endLength > 0) ? ("..." + message.substring(message.length() - endLength)) : "");
-                    }
-                } else if (StringUtils.isNotEmpty(rootCauseMessage)){
-                    message = rootCauseMessage;
-                } else if (null != rootCause){
-                    message = rootCause.getClass().getName();
+                logMessage = rootCauseMessage;
+            }
+        } else if (null != rootCause) {
+            logMessage = rootCause.getClass().getName();
+        }
+
+        if (StringUtils.isEmpty(logMessage)) {
+            logMessage = STR_NOT_AVAILABLE;
+        }
+
+        if ((rootCause instanceof SocketException) ||
+            (rootCause instanceof SocketTimeoutException) ||
+            (rootCause instanceof EOFException) ||
+            ((rootCause instanceof IOException) &&
+             ((lowerCaseRootCauseMessage.contains("broken pipe") ||
+               lowerCaseRootCauseMessage.contains(("connection reset")) ||
+               lowerCaseRootCauseMessage.contains(("invalid stream")))))) {
+
+            // ignore but trace socket exceptions; these may occur, when a connection timeout has happened
+            LOG.trace("DC caught an ignorable connection exception: {}", logMessage);
+        } else if (e instanceof OXException) {
+            // #DOCS-3981: recognize for specified log level for log category in case of OXException
+            final OXException oxExcp = (OXException) e;
+            final Category category = oxExcp.getCategory();
+            final LogLevel logLevel = (null != category) ?
+                (((Category.CATEGORY_USER_INPUT == category) || (Category.CATEGORY_PERMISSION_DENIED == category)) ? LogLevel.DEBUG : category.getLogLevel()) :
+                    LogLevel.ERROR;
+
+            switch (logLevel) {
+                case WARNING: {
+                    LOG.warn("DC caught a WARNING exception: {}", logMessage);
+                    break;
                 }
 
-                LOG.error(implGetLogMessage("DC caught an exception: \n" + message, null));
+                case INFO: {
+                    LOG.info("DC caught an INFO exception: {}", logMessage);
+                    break;
+                }
+
+                case DEBUG: {
+                    LOG.debug("DC caught a DEBUG exception: {}", logMessage);
+                    break;
+                }
+
+                case TRACE: {
+                    LOG.trace("DC caught a TRACE exception: {}", logMessage);
+                    break;
+                }
+
+                case ERROR:
+                default: {
+                    LOG.error("DC caught an exception: {}", logMessage);
+                    break;
+                }
             }
+        } else {
+            LOG.error("DC caught an exception: {}", logMessage);
         }
     }
 
