@@ -1,52 +1,26 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright autoRemoveer(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright autoRemoveer(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.documentconverter;
 
 import java.io.Closeable;
@@ -167,8 +141,8 @@ public class FileIdManager {
          *         The file is only valid until this {@link Closeable} object
          *         is finally closed.
          */
-        public File getDataFile() {
-            return m_dataFile;
+        public FileAndURL getDataFileAndURL() {
+            return m_dataFileAndURL;
         }
 
         /**
@@ -177,18 +151,21 @@ public class FileIdManager {
          * @param dataInputStream The data to be stored as temporary file.
          * @throws IOException
          */
-        public File setDataInputStream(@Nullable final InputStream dataInputStream) throws IOException {
+        public FileAndURL setDataInputStreamAndURL(@Nullable final InputStream dataInputStream, @Nullable String dataURL) throws IOException {
             implClearData();
 
             if (null != dataInputStream) {
-                if (null != (m_dataFile = m_manager.createTempFile("oxdcc"))) {
-                    FileUtils.copyInputStreamToFile(dataInputStream, m_dataFile);
+                File dataFile = null;
+
+                if (null != (dataFile = m_manager.createTempFile("oxdcc"))) {
+                    FileUtils.copyInputStreamToFile(dataInputStream, dataFile);
+                    m_dataFileAndURL = new FileAndURL(dataFile, dataURL);
                 } else {
                     throw new IOException("DC Client could not create temp. file");
                 }
             }
 
-            return m_dataFile;
+            return m_dataFileAndURL;
         }
 
         // - Implementation --------------------------------------------------------
@@ -197,9 +174,9 @@ public class FileIdManager {
          *
          */
         private void implClearData() {
-            if (null != m_dataFile) {
-                FileUtils.deleteQuietly(m_dataFile);
-                m_dataFile = null;
+            if (null != m_dataFileAndURL) {
+                FileUtils.deleteQuietly(m_dataFileAndURL.getFile());
+                m_dataFileAndURL = null;
             }
         }
 
@@ -211,7 +188,7 @@ public class FileIdManager {
 
         final private String m_fileId;
 
-        private File m_dataFile = null;
+        private FileAndURL m_dataFileAndURL = null;
     }
 
     /**
@@ -354,8 +331,8 @@ public class FileIdManager {
      * @return
      * @throws IOException
      */
-    public @Nullable File setDataInputStream(final String fileId, final InputStream dataInputStream) throws IOException {
-        File ret = null;
+    public @Nullable FileAndURL setDataInputStreamAndURL(final String fileId, final InputStream dataInputStream, final String dataURL) throws IOException {
+        FileAndURL ret = null;
 
         if ((null != fileId) && (null != dataInputStream)) {
             // no try-with-resource since we don't want to close FileIdData now;
@@ -364,7 +341,7 @@ public class FileIdManager {
 
             try {
                 fileIdData.updateTimestampMillis();
-                ret = fileIdData.setDataInputStream(dataInputStream);
+                ret = fileIdData.setDataInputStreamAndURL(dataInputStream, dataURL);
             } finally {
                 implUnlock(fileId);
             }
@@ -377,8 +354,8 @@ public class FileIdManager {
      * @param fileId
      * @return
      */
-    public @Nullable File getDataFile(final String fileId) {
-        File ret = null;
+    public @Nullable FileAndURL getDataFileAndURL(final String fileId) {
+        FileAndURL ret = null;
 
         if (null != fileId) {
             // no try-with-resource since we don't want to close FileIdData now;
@@ -386,7 +363,7 @@ public class FileIdManager {
             final FileIdData fileIdData = implLock(fileId, AUTOREMOVE_TIMEOUT_MILLIS_DEFAULT);
 
             try {
-                ret = fileIdData.getDataFile();
+                ret = fileIdData.getDataFileAndURL();
                 fileIdData.updateTimestampMillis();
             } finally {
                 implUnlock(fileId);
