@@ -1,52 +1,26 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.documentconverter;
 
 import java.io.BufferedOutputStream;
@@ -136,17 +110,6 @@ public class PDFExtractor {
        this(manager, pdfExecutable, maxVMemMB, 60000);
     }
 
-    /**
-     * Initializes a new {@link PDFExtractor} with a default timeout of 60000 milliseconds.
-     * @param manager
-     * @param pdfExecutable
-     * @param maxVMemMB
-     * @throws IOException
-     */
-    public PDFExtractor(@NonNull final DocumentConverterManager manager, @NonNull final File pdfExecutable) throws IOException {
-       this(manager, pdfExecutable, 1024);
-    }
-
     /**
      * getLogPrefix
      *
@@ -160,15 +123,6 @@ public class PDFExtractor {
      * @param pdfInputFile
      * @return
      */
-    public int getPageCount(@NonNull final File pdfInputFile) {
-        return getPageCount(pdfInputFile, null);
-    }
-
-    /**
-     * @param pdfInputFile
-     * @param fileName
-     * @return
-     */
     public int getPageCount(@NonNull final File pdfInputFile, @Nullable String fileName) {
         final File pdfWorkDir = m_manager.createTempDir("oxdccpdfpc");
         final File pdfPageCountOutputFile = new File(pdfWorkDir, "pagecount.json");
@@ -229,18 +183,6 @@ public class PDFExtractor {
      *  Values >0 represent a single page, that is to be extracted into the requested
      * @return The numeric errorCode of the extraction, with 0 indicating success.
      */
-    public int extractToGraphic(
-        @NonNull final File pdfInputFile,
-        @NonNull final File outputFile,
-        @NonNull final String targetFormatShortName,
-        final int pageNumber,
-        final int pixelWidth,
-        final int pixelHeight,
-        @Nullable String scaleType) throws Exception {
-
-        return extractToGraphic(pdfInputFile, outputFile, targetFormatShortName, pageNumber, pixelWidth, pixelHeight, scaleType, null);
-    }
-
     public int extractToGraphic(
         @NonNull final File pdfInputFile,
         @NonNull final File outputFile,
